.. AUTO-GENERATED FILE -- DO NOT EDIT!

API Reference for skimage |version|
===================================

Submodules
----------

- `skimage <skimage.html>`__

  - `color <skimage.color.html>`__

  - `data <skimage.data.html>`__

  - `draw <skimage.draw.html>`__

  - `exposure <skimage.exposure.html>`__

  - `feature <skimage.feature.html>`__

  - `filters <skimage.filters.html>`__

  - `future <skimage.future.html>`__

  - `graph <skimage.graph.html>`__

  - `io <skimage.io.html>`__

  - `measure <skimage.measure.html>`__

  - `metrics <skimage.metrics.html>`__

  - `morphology <skimage.morphology.html>`__

  - `registration <skimage.registration.html>`__

  - `restoration <skimage.restoration.html>`__

  - `segmentation <skimage.segmentation.html>`__

  - `transform <skimage.transform.html>`__

  - `util <skimage.util.html>`__

  - `viewer <skimage.viewer.html>`__

Submodule Contents
------------------

.. toctree::
   :maxdepth: 2

   skimage
   skimage.color
   skimage.data
   skimage.draw
   skimage.exposure
   skimage.feature
   skimage.filters
   skimage.filters.rank
   skimage.future
   skimage.future.graph
   skimage.graph
   skimage.io
   skimage.measure
   skimage.metrics
   skimage.morphology
   skimage.registration
   skimage.restoration
   skimage.segmentation
   skimage.transform
   skimage.util
   skimage.viewer
   skimage.viewer.canvastools
   skimage.viewer.plugins
   skimage.viewer.utils
   skimage.viewer.viewers
   skimage.viewer.widgets
